@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9401';
+$XML::MyXML::VERSION = '0.9402';
 use strict;
 use warnings;
 use Carp;
@@ -57,9 +57,9 @@ sub _decode {
 		if (exists $conv{$e}) { next; }
 		if (exists $replace{$e}) {
 			$conv{$e} = $replace{$e};
-		} elsif ($e =~ /^&#x([0-9a-fA-F]+);$/) {
+		} elsif ($e =~ /\A&#x([0-9a-fA-F]+);\z/) {
 			$conv{$e} = chr(hex($1));
-		} elsif ($e =~ /^&#([0-9]+);$/) {
+		} elsif ($e =~ /\A&#([0-9]+);\z/) {
 			$conv{$e} = chr($1);
 		}
 	}
@@ -72,14 +72,14 @@ sub _strip {
 	my $string = shift;
 
 	# NOTE: Replace this with the 'r' flag of the substitution operator
-	return defined $string ? ($string =~ /^\s*(.*?)\s*$/s)[0] : $string;
+	return defined $string ? ($string =~ /\A\s*(.*?)\s*\z/s)[0] : $string;
 }
 
 sub _strip_ns {
 	my $string = shift;
 
 	# NOTE: Replace this with the 'r' flag of the substitution operator
-	return defined $string ? ($string =~ /^(?:.+\:)?(.*)$/s)[0] : $string;
+	return defined $string ? ($string =~ /\A(?:.+\:)?(.*)\z/s)[0] : $string;
 }
 
 
@@ -101,7 +101,7 @@ sub xml_to_object {
 	my $xml = shift;
 	my $flags = shift || {};
 
-	if ($flags->{'file'}) {
+	if ($flags->{file}) {
 		open my $fh, '<', $xml	or croak "Error: The file '$xml' could not be opened for reading: $!";
 		$xml = join '', <$fh>;
 		close $fh;
@@ -126,13 +126,13 @@ sub xml_to_object {
 	{
 		my $init_ws = 1;
 		foreach my $el (@els) {
-			if ($el =~ /^<!--/) {
-				if ($el !~ /-->$/) { croak encode_utf8("Error: unclosed XML comment block - '$el'"); }
+			if ($el =~ /\A<!--/) {
+				if ($el !~ /-->\z/) { croak encode_utf8("Error: unclosed XML comment block - '$el'"); }
 				undef $el;
-			} elsif ($el =~ /^<\?/) { # like <?xml?> or <?target?>
-				if ($el !~ /\?>$/) { croak encode_utf8("Error: Erroneous special markup - '$el'"); }
+			} elsif ($el =~ /\A<\?/) { # like <?xml?> or <?target?>
+				if ($el !~ /\?>\z/) { croak encode_utf8("Error: Erroneous special markup - '$el'"); }
 				undef $el;
-			} elsif (my ($entname, undef, $entvalue) = $el =~ /^<!ENTITY\s+(\S+)\s+(['"])(.*?)\2\s*>$/g) {
+			} elsif (my ($entname, undef, $entvalue) = $el =~ /\A<!ENTITY\s+(\S+)\s+(['"])(.*?)\2\s*>\z/g) {
 				$entities->{"&$entname;"} = _decode($entvalue);
 				undef $el;
 			} elsif ($el =~ /<!/) { # like <!DOCTYPE> or <!ELEMENT> or <!ATTLIST>
@@ -152,67 +152,67 @@ sub xml_to_object {
 	my $object = bless ({ content => [] }, 'XML::MyXML::Object');
 	my $pointer = $object;
 	foreach my $el (@els) {
-		if ($el =~ /^<\/?>$/) {
+		if ($el =~ /\A<\/?>\z/) {
 			croak encode_utf8("Error: Strange element: '$el'");
-		} elsif ($el =~ /^<\/[^\s>]+>$/) {
-			my ($element) = $el =~ /^<\/(\S+)>$/g;
+		} elsif ($el =~ /\A<\/[^\s>]+>\z/) {
+			my ($element) = $el =~ /\A<\/(\S+)>\z/g;
 			if (! length($element)) { croak encode_utf8("Error: Strange element: '$el'"); }
-			if ($stack[-1]{'element'} ne $element) { croak encode_utf8("Error: Incompatible stack element: stack='".$stack[-1]{'element'}."' element='$el'"); }
+			if ($stack[-1]{element} ne $element) { croak encode_utf8("Error: Incompatible stack element: stack='".$stack[-1]{element}."' element='$el'"); }
 			my $stackentry = pop @stack;
-			if ($#{$stackentry->{'content'}} == -1) {
-				delete $stackentry->{'content'};
+			if ($#{$stackentry->{content}} == -1) {
+				delete $stackentry->{content};
 			}
-			$pointer = $stackentry->{'parent'};
-		} elsif ($el =~ /^<[^>]+\/>$/) {
-			my ($element) = $el =~ /^<([^\s>\/]+)/g;
+			$pointer = $stackentry->{parent};
+		} elsif ($el =~ /\A<[^>]+\/>\z/) {
+			my ($element) = $el =~ /\A<([^\s>\/]+)/g;
 			if (! length($element)) { croak encode_utf8("Error: Strange element: '$el'"); }
-			$el =~ s/^<\Q$element\E//;
-			$el =~ s/\/>$//;
+			$el =~ s/\A<\Q$element\E//;
+			$el =~ s/\/>\z//;
 			my @attrs = $el =~ /\s+(\S+=(['"]).*?\2)/g;
 			my $i = 1;
 			@attrs = grep {$i++ % 2} @attrs;
 			my %attr;
 			foreach my $attr (@attrs) {
-				my ($name, undef, $value) = $attr =~ /^(\S+?)=(['"])(.*?)\2$/g;
+				my ($name, undef, $value) = $attr =~ /\A(\S+?)=(['"])(.*?)\2\z/g;
 				if (! length($name) or ! defined($value)) { croak encode_utf8("Error: Strange attribute: '$attr'"); }
 				$attr{$name} = _decode($value, $entities);
 			}
 			my $entry = { element => $element, attrs => \%attr, parent => $pointer };
-			weaken( $entry->{'parent'} );
+			weaken( $entry->{parent} );
 			bless $entry, 'XML::MyXML::Object';
-			push @{$pointer->{'content'}}, $entry;
-		} elsif ($el =~ /^<[^\s>\/][^>]*>$/) {
-			my ($element) = $el =~ /^<([^\s>]+)/g;
+			push @{$pointer->{content}}, $entry;
+		} elsif ($el =~ /\A<[^\s>\/][^>]*>\z/) {
+			my ($element) = $el =~ /\A<([^\s>]+)/g;
 			if (! length($element)) { croak encode_utf8("Error: Strange element: '$el'"); }
-			$el =~ s/^<\Q$element\E//;
-			$el =~ s/>$//;
+			$el =~ s/\A<\Q$element\E//;
+			$el =~ s/>\z//;
 			my @attrs = $el =~ /\s+(\S+=(['"]).*?\2)/g;
 			my $i = 1;
 			@attrs = grep {$i++ % 2} @attrs;
 			my %attr;
 			foreach my $attr (@attrs) {
-				my ($name, undef, $value) = $attr =~ /^(\S+?)=(['"])(.*?)\2$/g;
+				my ($name, undef, $value) = $attr =~ /\A(\S+?)=(['"])(.*?)\2\z/g;
 				if (! length($name) or ! defined($value)) { croak encode_utf8("Error: Strange attribute: '$attr'"); }
 				$attr{$name} = _decode($value, $entities);
 			}
 			my $entry = { element => $element, attrs => \%attr, content => [], parent => $pointer };
-			weaken( $entry->{'parent'} );
+			weaken( $entry->{parent} );
 			bless $entry, 'XML::MyXML::Object';
 			push @stack, $entry;
-			push @{$pointer->{'content'}}, $entry;
+			push @{$pointer->{content}}, $entry;
 			$pointer = $entry;
-		} elsif ($el =~ /^[^<>]*$/) {
+		} elsif ($el =~ /\A[^<>]*\z/) {
 			my $entry = { value => _decode($el, $entities), parent => $pointer };
-			weaken( $entry->{'parent'} );
+			weaken( $entry->{parent} );
 			bless $entry, 'XML::MyXML::Object';
-			push @{$pointer->{'content'}}, $entry;
+			push @{$pointer->{content}}, $entry;
 		} else {
 			croak encode_utf8("Error: Strange element: '$el'");
 		}
 	}
-	if (@stack) { croak encode_utf8("Error: The <$stack[-1]{'element'}> element has not been closed in XML"); }
-	$object = $object->{'content'}[0];
-	$object->{'parent'} = undef;
+	if (@stack) { croak encode_utf8("Error: The <$stack[-1]{element}> element has not been closed in XML"); }
+	$object = $object->{content}[0];
+	$object->{parent} = undef;
 	return $object;
 }
 
@@ -221,19 +221,19 @@ sub _objectarray_to_xml {
 
 	my $xml = '';
 	foreach my $stuff (@$object) {
-		if (! defined $stuff->{'element'} and defined $stuff->{'value'}) {
-			$xml .= _encode($stuff->{'value'});
+		if (! defined $stuff->{element} and defined $stuff->{value}) {
+			$xml .= _encode($stuff->{value});
 		} else {
-			$xml .= "<".$stuff->{'element'};
-			foreach my $attrname (keys %{$stuff->{'attrs'}}) {
-				$xml .= " ".$attrname.'="'._encode($stuff->{'attrs'}{$attrname}).'"';
+			$xml .= "<".$stuff->{element};
+			foreach my $attrname (keys %{$stuff->{attrs}}) {
+				$xml .= " ".$attrname.'="'._encode($stuff->{attrs}{$attrname}).'"';
 			}
-			if (! defined $stuff->{'content'}) {
+			if (! defined $stuff->{content}) {
 				$xml .= "/>"
 			} else {
 				$xml .= ">";
-				$xml .= _objectarray_to_xml($stuff->{'content'});
-				$xml .= "</".$stuff->{'element'}.">";
+				$xml .= _objectarray_to_xml($stuff->{content});
+				$xml .= "</".$stuff->{element}.">";
 			}
 		}
 	}
@@ -255,13 +255,13 @@ sub _tidy_object {
 
 	my $indentstring = exists $flags->{indentstring} ? $flags->{indentstring} : "\t";
 
-	if (! defined $object->{'content'} or ! @{$object->{'content'}}) { return; }
+	if (! defined $object->{content} or ! @{$object->{content}}) { return; }
 	my $hastext;
-	my @children = @{$object->{'content'}};
+	my @children = @{$object->{content}};
 	foreach my $i (0..$#children) {
 		my $child = $children[$i];
-		if (defined $child->{'value'}) {
-			if ($child->{'value'} =~ /\S/) {
+		if (defined $child->{value}) {
+			if ($child->{value} =~ /\S/) {
 				$hastext = 1;
 				last;
 			}
@@ -269,22 +269,22 @@ sub _tidy_object {
 	}
 	if ($hastext) { return; }
 
-	@{$object->{'content'}} = grep { ! defined $_->{'value'} or $_->{'value'} !~ /^\s*$/ } @{$object->{'content'}};
+	@{$object->{content}} = grep { ! defined $_->{value} or $_->{value} !~ /\A\s*\z/ } @{$object->{content}};
 
-	@children = @{$object->{'content'}};
-	$object->{'content'} = [];
+	@children = @{$object->{content}};
+	$object->{content} = [];
 	for my $i (0..$#children) {
 		my $whitespace = bless ({ value => "\n".($indentstring x ($tabs+1)), parent => $object }, 'XML::MyXML::Object');
-		weaken( $whitespace->{'parent'} );
-		push @{$object->{'content'}}, $whitespace;
-		push @{$object->{'content'}}, $children[$i];
+		weaken( $whitespace->{parent} );
+		push @{$object->{content}}, $whitespace;
+		push @{$object->{content}}, $children[$i];
 	}
 	my $whitespace = bless ({ value => "\n".($indentstring x ($tabs)), parent => $object }, 'XML::MyXML::Object');
-	weaken( $whitespace->{'parent'} );
-	push @{$object->{'content'}}, $whitespace;
+	weaken( $whitespace->{parent} );
+	push @{$object->{content}}, $whitespace;
 
-	for my $i (0..$#{$object->{'content'}}) {
-		_tidy_object($object->{'content'}[$i], $tabs+1, $flags);
+	for my $i (0..$#{$object->{content}}) {
+		_tidy_object($object->{content}[$i], $tabs+1, $flags);
 	}
 }
 
@@ -297,7 +297,7 @@ sub simple_to_xml {
 	my $xml = '';
 	my ($key, $value, @residue) = (ref $arref eq 'HASH') ? %$arref : @$arref;
 	if (@residue) { croak "Error: the provided simple ref contains more than 1 top element"; }
-	my ($tag) = $key =~ /^(\S+)/g;
+	my ($tag) = $key =~ /\A(\S+)/g;
 	croak encode_utf8("Error: Strange key: $key") if ! defined $tag;
 
 	if (! ref $value) {
@@ -309,13 +309,13 @@ sub simple_to_xml {
 	} else {
 		$xml .= "<$key>"._arrayref_to_xml($value, $flags)."</$tag>";
 	}
-	if ($flags->{'tidy'}) { $xml = tidy_xml($xml, { $flags->{'indentstring'} ? (indentstring => $flags->{'indentstring'}) : () }); }
-	my $decl = $flags->{'complete'} ? '<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>'."\n" : '';
-	$decl .= "<?xml-stylesheet type=\"text/xsl\" href=\"$flags->{'xslt'}\"?>\n" if $flags->{'xslt'};
+	if ($flags->{tidy}) { $xml = tidy_xml($xml, { $flags->{indentstring} ? (indentstring => $flags->{indentstring}) : () }); }
+	my $decl = $flags->{complete} ? '<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>'."\n" : '';
+	$decl .= "<?xml-stylesheet type=\"text/xsl\" href=\"$flags->{xslt}\"?>\n" if $flags->{xslt};
 	$xml = $decl . $xml;
 
-	if (defined $flags->{'save'}) {
-		open my $fh, '>', $flags->{'save'} or croak "Error: Couldn't open file '$flags->{'save'}' for writing: $!";
+	if (defined $flags->{save}) {
+		open my $fh, '>', $flags->{save} or croak "Error: Couldn't open file '$flags->{save}' for writing: $!";
 		binmode $fh, ':encoding(UTF-8)';
 		print $fh $xml;
 		close $fh;
@@ -335,13 +335,10 @@ sub _arrayref_to_xml {
 	if (ref $arref eq 'HASH') { return _hashref_to_xml($arref, $flags); }
 
 	foreach (my $i = 0; $i <= $#$arref; ) {
-	#while (@$arref) {
 		my $key = $arref->[$i++];
-		#my $key = shift @$arref;
-		my ($tag) = $key =~ /^(\S+)/g;
+		my ($tag) = $key =~ /\A(\S+)/g;
 		croak encode_utf8("Error: Strange key: $key") if ! defined $tag;
 		my $value = $arref->[$i++];
-		#my $value = shift @$arref;
 
 		if ($key eq '!as_is') {
 			$xml .= $value if check_xml($value);
@@ -366,7 +363,7 @@ sub _hashref_to_xml {
 	my $xml = '';
 
 	while (my ($key, $value) = each %$hashref) {
-		my ($tag) = $key =~ /^(\S+)/g;
+		my ($tag) = $key =~ /\A(\S+)/g;
 		croak encode_utf8("Error: Strange key: $key") if ! defined $tag;
 
 		if ($key eq '!as_is') {
@@ -402,7 +399,7 @@ sub _objectarray_to_simple {
 
 	if (! defined $object) { return undef; }
 
-	if ($flags->{'arrayref'}) {
+	if ($flags->{arrayref}) {
 		return _objectarray_to_simple_arrayref($object, $flags);
 	} else {
 		return _objectarray_to_simple_hashref($object, $flags);
@@ -418,13 +415,13 @@ sub _objectarray_to_simple_hashref {
 	my $hashref = {};
 
 	foreach my $stuff (@$object) {
-		if (defined $stuff->{'element'}) {
-			my $key = $stuff->{'element'};
-			if ($flags->{'strip_ns'}) { $key = _strip_ns($key); }
-			$hashref->{ $key } = _objectarray_to_simple($stuff->{'content'}, $flags);
-		} elsif (defined $stuff->{'value'}) {
-			my $value = $stuff->{'value'};
-			if ($flags->{'strip'}) { $value = _strip($value); }
+		if (defined $stuff->{element}) {
+			my $key = $stuff->{element};
+			if ($flags->{strip_ns}) { $key = _strip_ns($key); }
+			$hashref->{ $key } = _objectarray_to_simple($stuff->{content}, $flags);
+		} elsif (defined $stuff->{value}) {
+			my $value = $stuff->{value};
+			if ($flags->{strip}) { $value = _strip($value); }
 			return $value if $value =~ /\S/;
 		}
 	}
@@ -445,14 +442,13 @@ sub _objectarray_to_simple_arrayref {
 	my $arrayref = [];
 
 	foreach my $stuff (@$object) {
-		if (defined $stuff->{'element'}) {
-			my $key = $stuff->{'element'};
-			if ($flags->{'strip_ns'}) { $key = _strip_ns($key); }
-			push @$arrayref, ( $key, _objectarray_to_simple($stuff->{'content'}, $flags) );
-			#$hashref->{ $key } = _objectarray_to_simple($stuff->{'content'}, $flags);
-		} elsif (defined $stuff->{'value'}) {
-			my $value = $stuff->{'value'};
-			if ($flags->{'strip'}) { $value = _strip($value); }
+		if (defined $stuff->{element}) {
+			my $key = $stuff->{element};
+			if ($flags->{strip_ns}) { $key = _strip_ns($key); }
+			push @$arrayref, ( $key, _objectarray_to_simple($stuff->{content}, $flags) );
+		} elsif (defined $stuff->{value}) {
+			my $value = $stuff->{value};
+			if ($flags->{strip}) { $value = _strip($value); }
 			return $value if $value =~ /\S/;
 		}
 	}
@@ -477,7 +473,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9401';
+$XML::MyXML::Object::VERSION = '0.9402';
 use Carp;
 use Encode;
 
@@ -494,7 +490,7 @@ sub new {
 sub _parse_description {
 	my ($desc) = @_;
 
-	my ($tag, $attrs_str) = $desc =~ /^([^\[]*)(.*)$/g;
+	my ($tag, $attrs_str) = $desc =~ /\A([^\[]*)(.*)\z/g;
 	my %attrs = $attrs_str =~ /\[([^\]=]+)(?:=(\"[^"]*\"|[^"\]]*))?\]/g;
 	foreach my $value (values %attrs) {
 		$value =~ s/\A\"//;
@@ -511,7 +507,7 @@ sub cmp_element {
 			? @$desc{qw/ tag attrs /}
 			: _parse_description($desc);
 
-	! length $tag or $self->{'element'} =~ /(^|\:)\Q$tag\E$/	or return 0;
+	! length $tag or $self->{element} =~ /(\A|\:)\Q$tag\E\z/	or return 0;
 	foreach my $attr (keys %$attrs) {
 		my $val = $self->attr($attr);
 		defined $val											or return 0;
@@ -527,7 +523,7 @@ sub children {
 
 	$tag = '' if ! defined $tag;
 
-	my @all_children = grep { defined $_->{'element'} } @{$self->{'content'}};
+	my @all_children = grep { defined $_->{element} } @{$self->{content}};
 	length $tag		or return @all_children;
 
 	($tag, my $attrs) = _parse_description($tag);
@@ -545,10 +541,10 @@ sub path {
 
 	my @path;
 	my $orig_path = $path;
-	my $start_root = $path =~ m!^/!;
+	my $start_root = $path =~ m!\A/!;
 	$path = "/" . $path		unless $start_root;
 	while (length $path) {
-		my $success = $path =~ s!^/((?:[^/\[]*)?(?:\[[^\]=]+(?:=(?:\"[^"]*\"|[^"\]]*))?\])*)!!;
+		my $success = $path =~ s!\A/((?:[^/\[]*)?(?:\[[^\]=]+(?:=(?:\"[^"]*\"|[^"\]]*))?\])*)!!;
 		my $seg = $1;
 		if ($success) {
 			push @path, $seg;
@@ -573,9 +569,9 @@ sub value {
 	my $self = shift;
 	my $flags = shift || {};
 
-	if ($self->{'content'} and $self->{'content'}[0]) {
-		my $value = $self->{'content'}[0]{'value'};
-		if ($flags->{'strip'}) { $value = XML::MyXML::_strip($value); }
+	if ($self->{content} and $self->{content}[0]) {
+		my $value = $self->{content}[0]{value};
+		if ($flags->{strip}) { $value = XML::MyXML::_strip($value); }
 		return $value;
 	} else {
 		return undef;
@@ -602,18 +598,18 @@ sub attr {
 	if (defined $attrname) {
 		if ($must_set) {
 			if (defined ($set_to)) {
-				$self->{'attrs'}{$attrname} = $set_to;
+				$self->{attrs}{$attrname} = $set_to;
 				return $set_to;
 			} else {
-				delete $self->{'attrs'}{$attrname};
+				delete $self->{attrs}{$attrname};
 				return;
 			}
 		} else {
-			my $attrvalue = $self->{'attrs'}->{$attrname};
+			my $attrvalue = $self->{attrs}->{$attrname};
 			return $attrvalue;
 		}
 	} else {
-		return %{$self->{'attrs'}};
+		return %{$self->{attrs}};
 	}
 }
 
@@ -622,9 +618,9 @@ sub tag {
 	my $self = shift;
 	my $flags = shift || {};
 
-	my $tag = $self->{'element'};
+	my $tag = $self->{element};
 	if (defined $tag) {
-		$tag =~ s/^.*\://	if $flags->{'strip_ns'};
+		$tag =~ s/\A.*\://	if $flags->{strip_ns};
 		return $tag;
 	} else {
 		return undef;
@@ -635,7 +631,7 @@ sub tag {
 sub parent {
 	my $self = shift;
 
-	return $self->{'parent'};
+	return $self->{parent};
 }
 
 
@@ -644,7 +640,7 @@ sub simplify {
 	my $flags = shift || {};
 
 	my $simple = XML::MyXML::_objectarray_to_simple([$self], $flags);
-	if (! $flags->{'internal'}) {
+	if (! $flags->{internal}) {
 		return $simple;
 	} else {
 		if (ref $simple eq 'HASH') {
@@ -660,12 +656,12 @@ sub to_xml {
 	my $self = shift;
 	my $flags = shift || {};
 
-	my $decl = $flags->{'complete'} ? '<?xml version="1.1" encoding="UTF-8" standalone="yes" ?>'."\n" : '';
+	my $decl = $flags->{complete} ? '<?xml version="1.1" encoding="UTF-8" standalone="yes" ?>'."\n" : '';
 	my $xml = XML::MyXML::_objectarray_to_xml([$self]);
-	if ($flags->{'tidy'}) { $xml = XML::MyXML::tidy_xml($xml, { %$flags, bytes => 0, complete => 0, save => undef }); }
+	if ($flags->{tidy}) { $xml = XML::MyXML::tidy_xml($xml, { %$flags, bytes => 0, complete => 0, save => undef }); }
 	$xml = $decl . $xml;
-	if (defined $flags->{'save'}) {
-		open my $fh, '>', $flags->{'save'} or croak "Error: Couldn't open file '$flags->{'save'}' for writing: $!";
+	if (defined $flags->{save}) {
+		open my $fh, '>', $flags->{save} or croak "Error: Couldn't open file '$flags->{save}' for writing: $!";
 		binmode $fh, ':encoding(UTF-8)';
 		print $fh $xml;
 		close $fh;
@@ -700,7 +696,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9401
+version 0.9402
 
 =head1 SYNOPSIS
 
